====
Time
====

Sub-commands to support time definition

.. autosummary::
    :nosignatures:
    :toctree: _generated/

    rompy_swan.subcomponents.time.Time
    rompy_swan.subcomponents.time.Delt
    rompy_swan.subcomponents.time.TimeRangeOpen
    rompy_swan.subcomponents.time.TimeRangeClosed
    rompy_swan.subcomponents.time.NONSTATIONARY
    rompy_swan.subcomponents.time.STATIONARY
